#
# spec file for package susepaste
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           susepaste
Version:        20241225
Release:        1.1
Summary:        Script for using openSUSE paste
License:        GPL-3.0-only
Group:          Productivity/Other
URL:            https://github.com/openSUSE/paste
Source0:        susepaste-script.tar.xz
Patch1:         update.patch
Requires:       bash
Requires:       curl
BuildArch:      noarch

%description
A script for using the openSUSE paste service.
You can paste either the file or input from stdin.

%package screenshot
Summary:        Script for pasting screenshots
Group:          Productivity/Other
Requires:       ImageMagick
Requires:       curl
Requires:       wmctrl
Recommends:     xclip
BuildArch:      noarch

%description screenshot
A script for using the openSUSE paste service.
You can paste screenshot of the window or whole desktop.

%prep
%autosetup -n susepaste-script -p 1
mv script/gpl-3.0.txt COPYING

%build

%install
pushd script
install -Dpm 0755 susepaste \
  %{buildroot}%{_bindir}/susepaste
install -Dpm 0755 susepaste-screenshot \
  %{buildroot}%{_bindir}/susepaste-screenshot
install -Dpm 0644 susepaste.1 \
  %{buildroot}%{_mandir}/man1/susepaste.1
install -Dpm 0644 susepaste-screenshot.1 \
  %{buildroot}%{_mandir}/man1/susepaste-screenshot.1
install -Dpm 0644 lang-mappings.sed \
  %{buildroot}%{_datadir}/susepaste/lang-mappings.sed
popd

%files
%license COPYING
%{_bindir}/%{name}
%{_datadir}/susepaste/lang-mappings.sed
%dir %{_datadir}/susepaste
%{_mandir}/man1/%{name}.1%{?ext_man}

%files screenshot
%license COPYING
%{_bindir}/%{name}-screenshot
%{_mandir}/man1/%{name}-screenshot.1%{?ext_man}

%changelog
* Wed Dec 25 2024 Stephan Hemeier <Sauerlandlinux@gmx.de>
- Update to Version 20241225
  * Update the update.patch
* Sat Dec  7 2024 Stephan Hemeier <Sauerlandlinux@gmx.de>
- Updated to version 20241207
  * Repair susepaste-screenshot
  * handle multiple login sessions
  * Update manpage
* Fri May 31 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Update to version 0.7 (commit dbdce91bfd7954616731e47f97f82b8e10586101):
  * Remove susepaste.org from output, use paste.opensuse.org exclusively
  * Repair X11 clipboard copy (use clipboard instead of XA_CLIPBOARD)
  * Support Wayland clipboard copy
- Drop upstreamed patches:
  * 0001-susepaste-Fix-parsing-of-returned-Location-header.patch
  * 0002-susepaste-add-image-paste-info.patch
  * 0003-susepaste-use-paste-opensuse.org.patch
- Disable submodules in service, linked forge is offline
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Nov 13 2023 Jan Engelhardt <jengelh@inai.de>
- Fix homepage URL
- Add _service file (use on next release)
* Thu Dec  8 2022 Jacob Michalskie <hellcp@opensuse.org>
- Add 0003-susepaste-use-paste-opensuse.org.patch: Replace
  susepaste.org submission address with paste.opensuse.org
* Sat Dec  4 2021 malcolmlewis@opensuse.org
- Add 0002-susepaste-add-image-paste-info.patch: Add info on
  posting an image to susepaste in the man page, (boo#1193400).
* Tue Mar 31 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add 0001-susepaste-Fix-parsing-of-returned-Location-header.patch:
  fix parsing of location header returned by susepaste.org
  (boo#1166669).
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Trim duplicated wording from descriptions.
* Sun Aug 11 2019 Michal Hrusecky <michal.hrusecky@opensuse.org>
- updated to version 0.6
  - error out when pasting unreadable file
  - fix one bashism
  - allow to specify protocol
* Sun Nov 26 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
* Fri Dec 16 2011 mhrusecky@suse.cz
- minor spec file beautifications
* Thu Apr 21 2011 mhrusecky@suse.cz
- updated to version 0.5
  - support for pasting with key
  - fixed infinite loop on syntax error
* Sun Jan  2 2011 mhrusecky@suse.cz
- updated to version 0.4.1
  - fixed screenshot pasting script to cleanup temporaly files
* Sat Jan  1 2011 mhrusecky@suse.cz
- updated to version 0.4
  - adding screenshot pasting script
* Mon Dec  6 2010 mhrusecky@suse.cz
- updated to version 0.3
  - support for commandline option
  - support for pasting images
  - automatic recognition of several file types
* Mon Aug 30 2010 mhrusecky@suse.cz
- adding http://paste.opensuse.org as another output
- adding man page
* Fri Jul 30 2010 mhrusecky@suse.cz
- packaged first version of the script
